summaryrefslogtreecommitdiff
path: root/searx/engines/duckduckgo.py
diff options
context:
space:
mode:
authorBnyro <bnyro@tutanota.com>2024-10-09 11:59:31 +0200
committerBnyro <bnyro@tutanota.com>2024-11-24 12:41:57 +0100
commitf31a3a2053b07b834c5143bd6be4eaf05c1a014d (patch)
tree9f74011af2301a313b6780e711324efd88435b70 /searx/engines/duckduckgo.py
parent0253c10b522fe2e8206db78e37066771ce90cf92 (diff)
downloadsearxng-f31a3a2053b07b834c5143bd6be4eaf05c1a014d.tar.gz
searxng-f31a3a2053b07b834c5143bd6be4eaf05c1a014d.zip
[chore] *: fix typos detected by typos-cli
Diffstat (limited to 'searx/engines/duckduckgo.py')
-rw-r--r--searx/engines/duckduckgo.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/searx/engines/duckduckgo.py b/searx/engines/duckduckgo.py
index 36125556b..82b37f9d1 100644
--- a/searx/engines/duckduckgo.py
+++ b/searx/engines/duckduckgo.py
@@ -42,7 +42,7 @@ about = {
}
send_accept_language_header = True
"""DuckDuckGo-Lite tries to guess user's prefered language from the HTTP
``Accept-Language``. Optional the user can select a region filter (but not a
language).
"""
@@ -402,7 +402,7 @@ def fetch_traits(engine_traits: EngineTraits):
"""Fetch languages & regions from DuckDuckGo.
SearXNG's ``all`` locale maps DuckDuckGo's "Alle regions" (``wt-wt``).
- DuckDuckGo's language "Browsers prefered language" (``wt_WT``) makes no
+ DuckDuckGo's language "Browsers preferred language" (``wt_WT``) makes no
sense in a SearXNG request since SearXNG's ``all`` will not add a
``Accept-Language`` HTTP header. The value in ``engine_traits.all_locale``
is ``wt-wt`` (the region).
@@ -42,7 +42,7 @@ about = {
}
send_accept_language_header = True
-"""DuckDuckGo-Lite tries to guess user's prefered language from the HTTP
+"""DuckDuckGo-Lite tries to guess user's preferred language from the HTTP
``Accept-Language``. Optional the user can select a region filter (but not a
language).